# Generated by Django 2.2.14 on 2020-07-02 15:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0098_auto_20200629_1756'),
    ]

    operations = [
        migrations.AlterField(
            model_name='enterprisecourseenrollment',
            name='marked_done',
            field=models.NullBooleanField(default=False, help_text='Specifies whether a user marked this course as completed in the learner portal.'),
        ),
        migrations.AlterField(
            model_name='historicalenterprisecourseenrollment',
            name='marked_done',
            field=models.NullBooleanField(default=False, help_text='Specifies whether a user marked this course as completed in the learner portal.'),
        ),
    ]
