# -*- coding: utf-8 -*-
# Generated by Django 1.10.3 on 2016-11-21 02:41


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0005_pendingenterprisecustomeruser'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pendingenterprisecustomeruser',
            name='user_email',
            field=models.EmailField(max_length=254, unique=True),
        ),
    ]
